==> pegasus-merchandise-api-3.12.5-sources.jar: com/thebeastshop/pegasus/merchandise/vo/ProductKnowledgeVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

public class ProductKnowledgeVO implements Serializable {

    private String productCode;
    private String productName;
    private String brands;

    private String category;
    /*
    规格列表
     */
    private List<AttributeInfoVO> attributeInfos;


    private BigDecimal price;

    private BigDecimal minPrice;

    private BigDecimal maxPrice;

    private String allowCampaign;

    private String allowCoupon;

    private String allowVipDiscount;


    private String allowBdDiscount;
   /*
   商品图
    */
    private String productUrls;

   /*
   同系列商品
    */
    private List<String> relationProducts;

    /*
    推荐商品
     */
    private List<String> recommendProducts;

    private List<String> campaignTitles;

    /*
    商详页介绍
     */
    private String content;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getBrands() {
        return brands;
    }

    public void setBrands(String brands) {
        this.brands = brands;
    }

    public List<AttributeInfoVO> getAttributeInfos() {
        return attributeInfos;
    }

    public void setAttributeInfos(List<AttributeInfoVO> attributeInfos) {
        this.attributeInfos = attributeInfos;
    }

    public String getAllowCampaign() {
        return allowCampaign;
    }

    public void setAllowCampaign(String allowCampaign) {
        this.allowCampaign = allowCampaign;
    }

    public String getAllowCoupon() {
        return allowCoupon;
    }

    public void setAllowCoupon(String allowCoupon) {
        this.allowCoupon = allowCoupon;
    }

    public String getAllowVipDiscount() {
        return allowVipDiscount;
    }

    public void setAllowVipDiscount(String allowVipDiscount) {
        this.allowVipDiscount = allowVipDiscount;
    }

    public String getAllowBdDiscount() {
        return allowBdDiscount;
    }

    public void setAllowBdDiscount(String allowBdDiscount) {
        this.allowBdDiscount = allowBdDiscount;
    }

    public String getProductUrls() {
        return productUrls;
    }

    public void setProductUrls(String productUrls) {
        this.productUrls = productUrls;
    }

    public List<String> getRelationProducts() {
        return relationProducts;
    }

    public void setRelationProducts(List<String> relationProducts) {
        this.relationProducts = relationProducts;
    }

    public List<String> getRecommendProducts() {
        return recommendProducts;
    }

    public void setRecommendProducts(List<String> recommendProducts) {
        this.recommendProducts = recommendProducts;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(BigDecimal minPrice) {
        this.minPrice = minPrice;
    }

    public BigDecimal getMaxPrice() {
        return maxPrice;
    }

    public void setMaxPrice(BigDecimal maxPrice) {
        this.maxPrice = maxPrice;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public List<String> getCampaignTitles() {
        return campaignTitles;
    }

    public void setCampaignTitles(List<String> campaignTitles) {
        this.campaignTitles = campaignTitles;
    }

}

==> pegasus-merchandise-api-4.0.4-sources.jar: com/thebeastshop/pegasus/merchandise/vo/ProductKnowledgeVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

public class ProductKnowledgeVO implements Serializable {

    private String productCode;
    private String productName;
    private String brands;

    private String category;
    /*
    规格列表
     */
    private List<AttributeInfoVO> attributeInfos;


    private BigDecimal price;

    private BigDecimal minPrice;

    private BigDecimal maxPrice;

    private String allowCampaign;

    private String allowCoupon;

    private String allowVipDiscount;


    private String allowBdDiscount;
   /*
   商品图
    */
    private String productUrls;

   /*
   同系列商品
    */
    private List<String> relationProducts;

    /*
    推荐商品
     */
    private List<String> recommendProducts;

    private List<String> campaignTitles;


    private String bagSkuName;

    private String onShelfStatus;

    /*
    商详页介绍
     */
    private String content;

    private List<KnowledgeKeywordAiVO> productKnowledges;


    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getBrands() {
        return brands;
    }

    public void setBrands(String brands) {
        this.brands = brands;
    }

    public List<AttributeInfoVO> getAttributeInfos() {
        return attributeInfos;
    }

    public void setAttributeInfos(List<AttributeInfoVO> attributeInfos) {
        this.attributeInfos = attributeInfos;
    }

    public String getAllowCampaign() {
        return allowCampaign;
    }

    public void setAllowCampaign(String allowCampaign) {
        this.allowCampaign = allowCampaign;
    }

    public String getAllowCoupon() {
        return allowCoupon;
    }

    public void setAllowCoupon(String allowCoupon) {
        this.allowCoupon = allowCoupon;
    }

    public String getAllowVipDiscount() {
        return allowVipDiscount;
    }

    public void setAllowVipDiscount(String allowVipDiscount) {
        this.allowVipDiscount = allowVipDiscount;
    }

    public String getAllowBdDiscount() {
        return allowBdDiscount;
    }

    public void setAllowBdDiscount(String allowBdDiscount) {
        this.allowBdDiscount = allowBdDiscount;
    }

    public String getProductUrls() {
        return productUrls;
    }

    public void setProductUrls(String productUrls) {
        this.productUrls = productUrls;
    }

    public List<String> getRelationProducts() {
        return relationProducts;
    }

    public void setRelationProducts(List<String> relationProducts) {
        this.relationProducts = relationProducts;
    }

    public List<String> getRecommendProducts() {
        return recommendProducts;
    }

    public void setRecommendProducts(List<String> recommendProducts) {
        this.recommendProducts = recommendProducts;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public List<KnowledgeKeywordAiVO> getProductKnowledges() {
        return productKnowledges;
    }

    public void setProductKnowledges(List<KnowledgeKeywordAiVO> productKnowledges) {
        this.productKnowledges = productKnowledges;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(BigDecimal minPrice) {
        this.minPrice = minPrice;
    }

    public BigDecimal getMaxPrice() {
        return maxPrice;
    }

    public void setMaxPrice(BigDecimal maxPrice) {
        this.maxPrice = maxPrice;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public List<String> getCampaignTitles() {
        return campaignTitles;
    }

    public void setCampaignTitles(List<String> campaignTitles) {
        this.campaignTitles = campaignTitles;
    }

    public String getBagSkuName() {
        return bagSkuName;
    }

    public void setBagSkuName(String bagSkuName) {
        this.bagSkuName = bagSkuName;
    }

    public String getOnShelfStatus() {
        return onShelfStatus;
    }

    public void setOnShelfStatus(String onShelfStatus) {
        this.onShelfStatus = onShelfStatus;
    }





}
